@@ -26,7 +26,7 @@
  ** 									     ** 
  ** ************************************************************************ **/
 
-static char Id[] = "@(#)$Id: cmdLog.c,v 1.5.4.1 2006/04/20 22:35:33 rkowen Exp $";
+static char Id[] = "@(#)$Id: cmdLog.c,v 1.5.14.2 2009/07/30 18:03:19 rkowen Exp $";
 static void *UseId[] = { &UseId, Id };
 
 /** ************************************************************************ **/
@@ -89,7 +89,7 @@ static	char	_none[] = "none";
  **			int		 argc		Number of arguments  **
  **			char		*argv[]		Argument array	     **
  ** 									     **
- **   Result:		int	TCL_OK		Successfull completion	     **
+ **   Result:		int	TCL_OK		Successful completion	     **
  **				TCL_ERROR	Any error		     **
  ** 									     **
  **   Attached Globals:	tracelist	List containing all tracing settings **
@@ -149,7 +149,7 @@ int	cmdModuleLog(	ClientData	 client_data,
     /**
      **  Allocate memory for the facility list
      **/
-    if((char *) NULL == (faclist = (char *) malloc( alc_len)))
+    if((char *) NULL == (faclist = (char *) module_malloc( alc_len)))
 	return(( OK == ErrorLogger( ERR_ALLOC, LOC, NULL)) ?
 	    TCL_OK : TCL_ERROR);
 
