@@ -31,7 +31,7 @@
  ** 									     ** 
  ** ************************************************************************ **/
 
-static char Id[] = "@(#)$Id: cmdModule.c,v 1.11.2.2 2006/02/21 22:26:56 rkowen Exp $";
+static char Id[] = "@(#)$Id: cmdModule.c,v 1.11.2.2.14.2 2009/07/30 18:03:20 rkowen Exp $";
 static void *UseId[] = { &UseId, Id };
 
 /** ************************************************************************ **/
@@ -106,7 +106,7 @@ char	 *module_command;
  **			int		 argc		Number of arguments  **
  **			char		*argv[]		Argument array	     **
  ** 									     **
- **   Result:		int	TCL_OK		Successfull completion	     **
+ **   Result:		int	TCL_OK		Successful completion	     **
  **				TCL_ERROR	Any error		     **
  ** 									     **
  **   Attached Globals:	g_flags		These are set up accordingly before  **
@@ -446,7 +446,7 @@ int	cmdModule(	ClientData	 client_data,
  **   Parameters:	Tcl_Interp	*interp		According Tcl interp.**
  **		 	char		*filename			     **
  ** 									     **
- **   Result:		int	TCL_OK		Successfull completion	     **
+ **   Result:		int	TCL_OK		Successful completion	     **
  **				TCL_BREAK	break command		     **
  **				TCL_ERROR	Any error		     **
  ** 									     **
@@ -522,7 +522,7 @@ int   Read_Modulefile( Tcl_Interp	*interp,
  **   Parameters:	Tcl_Interp	*interp		According Tcl interp.**
  **		 	char		*filename			     **
  ** 									     **
- **   Result:		int	TCL_OK		Successfull completion	     **
+ **   Result:		int	TCL_OK		Successful completion	     **
  **				TCL_ERROR	Any error		     **
  ** 									     **
  **   Attached Globals:	line		Input read buffer		     **
@@ -549,7 +549,7 @@ int	 Execute_TclFile(	Tcl_Interp	*interp,
      **/
 
     if( line == NULL) {
-        if( NULL == (line = (char*) malloc( LINELENGTH * sizeof( char)))) {
+        if( NULL == (line = (char*) module_malloc(LINELENGTH * sizeof(char)))) {
 	    if( OK != ErrorLogger( ERR_ALLOC, LOC, NULL))
 		return( TCL_ERROR);	/** -------- EXIT (FAILURE) -------> **/
         }
@@ -694,7 +694,7 @@ int	 Execute_TclFile(	Tcl_Interp	*interp,
  **			int		 suppress_output  Controlls redirect.**
  **							of stdout and stderr **
  ** 									     **
- **   Result:		int	TCL_OK		Successfull completion	     **
+ **   Result:		int	TCL_OK		Successful completion	     **
  **				TCL_ERROR	Any error		     **
  ** 									     **
  **   Attached Globals:	-						     **
