@@ -30,7 +30,7 @@
  ** 									     ** 
  ** ************************************************************************ **/
 
-static char Id[] = "@(#)$Id: cmdPath.c,v 1.10.6.1.10.1 2007/02/14 05:38:21 rkowen Exp $";
+static char Id[] = "@(#)$Id: cmdPath.c,v 1.10.6.1.14.3 2009/07/30 18:03:20 rkowen Exp $";
 static void *UseId[] = { &UseId, Id };
 
 /** ************************************************************************ **/
@@ -106,7 +106,7 @@ static int	Remove_Path( Tcl_Interp	*interp, char *variable, char *item,
  **			int		 argc		Number of arguments  **
  **			char		*argv[]		Argument array	     **
  ** 									     **
- **   Result:		int	TCL_OK		Successfull completion	     **
+ **   Result:		int	TCL_OK		Successful completion	     **
  **				TCL_ERROR	Any error		     **
  ** 									     **
  **   Attached Globals:	g_flags		These are set up accordingly before  **
@@ -324,7 +324,22 @@ int	cmdSetPath(	ClientData	 client_data,
 	     **  Append/Prepend marker found
 	     **/
 	    if( append) {
-		char ch = *endp;
+		char ch = *startp;
+		*startp = '\0';
+		strcpy(newpath, oldpath);
+                /**
+                 ** check that newpath has a value before adding delim
+                 **/
+		if (strlen(newpath) > 0 && newpath[strlen(newpath)-1] != *delim)
+			strcat(newpath, delim);
+		strcat(newpath, qualifiedpath);
+		if (newpath[strlen(newpath)-1] != *delim)
+			strcat(newpath, delim);
+		*startp = ch;
+		strcat(newpath, startp);
+               
+	    } else {
+                char ch = *endp;
 		*endp = '\0';
 		strcpy(newpath, oldpath);
 		if (newpath[strlen(newpath)-1] != *delim)
@@ -332,17 +347,6 @@ int	cmdSetPath(	ClientData	 client_data,
 		strcat(newpath, qualifiedpath);
 		*endp = ch;
 		strcat(newpath, endp);
-	    } else {
-		char ch = *startp;
-		*startp = '\0';
-		strcpy(newpath, oldpath);
-		if (newpath[strlen(newpath)-1] != *delim)
-			strcat(newpath, delim);
-		strcpy(newpath, qualifiedpath);
-		if (*oldpath != *delim)	strcat(newpath, delim);
-		strcat(newpath, oldpath);
-		*startp = ch;
-		strcat(newpath, startp);
 	    }
 
 	} else {
@@ -412,7 +416,7 @@ unwind0:
  **			int		 argc		Number of arguments  **
  **			char		*argv[]		Argument array	     **
  ** 									     **
- **   Result:		int	TCL_OK		Successfull completion	     **
+ **   Result:		int	TCL_OK		Successful completion	     **
  **				TCL_ERROR	Any error		     **
  ** 									     **
  **   Attached Globals:	g_flags		These are set up accordingly before  **
@@ -553,7 +557,7 @@ unwind0:
  **			char		*sw_marker	Switch marker	     **
  **			const char	*delim		path delimiter	     **
  ** 									     **
- **   Result:		int	TCL_OK		Successfull completion	     **
+ **   Result:		int	TCL_OK		Successful completion	     **
  **				TCL_ERROR	Any error		     **
  ** 									     **
  **   Attached Globals:	g_flags		These are set up accordingly before  **
