@@ -30,7 +30,7 @@
  ** 									     ** 
  ** ************************************************************************ **/
 
-static char Id[] = "@(#)$Id: error.c,v 1.8.6.1.8.2 2007/02/14 06:09:04 rkowen Exp $";
+static char Id[] = "@(#)$Id: error.c,v 1.8.6.1.12.3 2009/07/30 20:10:00 rkowen Exp $";
 static void *UseId[] = { &UseId, Id };
 
 /** ************************************************************************ **/
@@ -248,7 +248,7 @@ static	ErrTransTab	TransTab[] = {
     { NO_ERR_START,	WGHT_DEBUG, "Starting $*" },
     { NO_ERR_END,	WGHT_DEBUG, "Exit $*" },
     { NO_ERR_VERBOSE,	WGHT_VERBOSE,  NULL },
-    { ERR_PARAM,	WGHT_ERROR, "Paramter error concerning '$1'" },
+    { ERR_PARAM,	WGHT_ERROR, "Parameter error concerning '$1'" },
     { ERR_USAGE,	WGHT_ERROR, "Usage is '$*'" },
     { ERR_ARGSTOLONG,	WGHT_ERROR, "'$1': Arguments too long. Max. is '$2'" },
     { ERR_OPT_AMBIG,	WGHT_ERROR, "Option '$1' is ambiguous" },
@@ -338,7 +338,7 @@ static	ErrTransTab	TransTab[] = {
     { ERR_INVAL,	WGHT_PANIC, "Invalid error type '$1' found" },
     { ERR_INVWGHT,	WGHT_PANIC, "Invalid error weight '$1' found" },
     { ERR_INVFAC,	WGHT_PANIC, "Invalid log facility '$1'" },
-    { ERR_ENVVAR,       WGHT_FATAL, "The environment variables LOADMODULES and _LMFILES_ have inconsistent lengths." }
+    { ERR_ENVVAR,       WGHT_FATAL, "The environment variables LOADEDMODULES and _LMFILES_ have inconsistent lengths." }
 };
 
 /** ************************************************************************ **/
