@@ -33,7 +33,7 @@
  ** 									     ** 
  ** ************************************************************************ **/
 
-static char Id[] = "@(#)$Id: locate_module.c,v 1.14.10.2 2007/02/14 06:09:04 rkowen Exp $";
+static char Id[] = "@(#)$Id: locate_module.c,v 1.14.14.2 2009/07/30 18:03:21 rkowen Exp $";
 static void *UseId[] = { &UseId, Id };
 
 /** ************************************************************************ **/
@@ -513,7 +513,7 @@ unwindt:
 	} else {     /** if( $path/$prefix/$mod is a directory) **/
 	    /**
 	     **  Now 'mod' should be either a file or the word 'default'
-	     **  In case of default get the file with the highest verion number
+	     **  In case of default get the file with the highest version number
 	     **  in the current directory
 	     **/
 	    if( is_def) {
@@ -534,7 +534,7 @@ unwindt:
 		for( i=0; i<numlist && Result==NULL; i++) {
 		    /**
 		     **  Build the full path name and check if it is a
-		     **  directory. If it is, recursivly try to find there what
+		     **  directory. If it is, recursively try to find there what
 		     **  we're seeking for
 		     **/
 		    if ((char *)NULL == stringer(fullpath, MOD_BUFSIZE,
@@ -750,7 +750,7 @@ char	**SortedDirList(	Tcl_Interp	*interp,
 	     **/
 	    if( j == n)
 		if( NULL == (filelist =
-		    (char**) realloc((char*) filelist, n *= 2)))
+		    (char**) realloc((char*) filelist, (n*=2)*sizeof(char*))))
 		    if( OK != ErrorLogger( ERR_ALLOC, LOC, NULL))
 			goto unwindt;
 	    /**
@@ -894,7 +894,7 @@ char	**SplitIntoList(	Tcl_Interp	*interp,
      **  the list.
      **  Copy the passed path into the new buffer.
      **/
-    if((char **) NULL == (pathlist = (char**) calloc( n = 100, sizeof( char*))))
+    if((char **) NULL == (pathlist = (char**) calloc(n = 100,sizeof( char*))))
 	if( OK != ErrorLogger( ERR_ALLOC, LOC, NULL))
 	    goto unwind1;
     /**
@@ -909,7 +909,7 @@ char	**SplitIntoList(	Tcl_Interp	*interp,
 	 **/
 	if( i == n )
 	    if((char **) NULL == (pathlist = (char**) realloc((char*) pathlist,
-		n *= 2)))
+		(n *= 2)*sizeof(char*))))
 		if( OK != ErrorLogger( ERR_ALLOC, LOC, NULL))
 		    goto unwind1;
 	/**
@@ -1205,7 +1205,7 @@ int SourceVers( Tcl_Interp *interp, char *path, char *name)
      **/
     null_free((void *) &buffer);
     /**
-     **  Result determines if this was successfull
+     **  Result determines if this was successful
      **/
 
     return( Result);
